pub struct Descriptor<T: AsGatt + ?Sized> { /* private fields */ }Expand description
Characteristic descriptor handle.
Implementations
Sourceimpl<T: AsGatt + ?Sized> Descriptor<T>
impl<T: AsGatt + ?Sized> Descriptor<T>
Sourcepub fn set<M: RawMutex, P: PacketPool, const AT: usize, const CN: usize>(
&self,
server: &AttributeServer<'_, M, P, AT, CN>,
value: &T,
) -> Result<(), Error>
pub fn set<M: RawMutex, P: PacketPool, const AT: usize, const CN: usize>( &self, server: &AttributeServer<'_, M, P, AT, CN>, value: &T, ) -> Result<(), Error>
Set the value of the descriptor in the provided attribute server.
Sourcepub fn get<M: RawMutex, P: PacketPool, const AT: usize, const CN: usize>(
&self,
server: &AttributeServer<'_, M, P, AT, CN>,
) -> Result<T, Error>where
T: FromGatt,
pub fn get<M: RawMutex, P: PacketPool, const AT: usize, const CN: usize>(
&self,
server: &AttributeServer<'_, M, P, AT, CN>,
) -> Result<T, Error>where
T: FromGatt,
Read the value of the descriptor.
If the descriptor for the handle cannot be found, an error is returned.